@@ -98,10 +98,11 @@ public:
     LatticeNode *prev() const { return prev_; }
     void setPrev(LatticeNode *prev) { prev_ = prev; }
 
+    /// Return the full word till the begining of the sentence.
     std::string fullWord() const {
         size_t length = 0;
-        auto pivot = this;
-        while (pivot != nullptr) {
+        const auto *pivot = this;
+        while (pivot) {
             length += pivot->word().size();
             pivot = pivot->prev();
         }
@@ -109,8 +110,8 @@ public:
         std::string result;
         result.resize(length);
         pivot = this;
-        while (pivot != nullptr) {
-            auto &word = pivot->word();
+        while (pivot) {
+            const auto &word = pivot->word();
             length -= word.size();
             std::copy(word.begin(), word.end(), result.begin() + length);
             pivot = pivot->prev();
@@ -121,9 +122,9 @@ public:
 
     SentenceResult toSentenceResult(float adjust = 0.0f) const {
         SentenceResult::Sentence result;
-        auto pivot = this;
+        const auto *pivot = this;
         // to skip bos
-        while (pivot->prev() != nullptr) {
+        while (pivot->prev()) {
             if (pivot->to()) {
                 result.emplace_back(pivot);
             }
